@@ -1,10 +1,10 @@
-/* $Id: SUPDrvSem.cpp 102121 2015-08-14 15:16:38Z bird $ */
+/* $Id: SUPDrvSem.cpp 118839 2017-10-28 15:14:05Z bird $ */
 /** @file
  * VBoxDrv - The VirtualBox Support Driver - Common OS agnostic.
  */
 
 /*
- * Copyright (C) 2006-2015 Oracle Corporation
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -60,7 +60,7 @@
 static DECLCALLBACK(void) supR0SemEventDestructor(void *pvObj, void *pvUser1, void *pvUser2)
 {
     Assert(pvUser2 == NULL);
-    NOREF(pvObj);
+    RT_NOREF2(pvObj, pvUser2);
     RTSemEventDestroy((RTSEMEVENT)pvUser1);
 }
 
@@ -217,6 +217,7 @@ SUPDECL(int) SUPSemEventWaitNsRelIntr(PSUPDRVSESSION pSession, SUPSEMEVENT hEven
 
 SUPDECL(uint32_t) SUPSemEventGetResolution(PSUPDRVSESSION pSession)
 {
+    RT_NOREF1(pSession);
     Assert(SUP_IS_SESSION_VALID(pSession));
     return RTSemEventGetResolution();
 }
@@ -232,7 +233,7 @@ SUPDECL(uint32_t) SUPSemEventGetResolution(PSUPDRVSESSION pSession)
 static DECLCALLBACK(void) supR0SemEventMultiDestructor(void *pvObj, void *pvUser1, void *pvUser2)
 {
     Assert(pvUser2 == NULL);
-    NOREF(pvObj);
+    RT_NOREF2(pvObj, pvUser2);
     RTSemEventMultiDestroy((RTSEMEVENTMULTI)pvUser1);
 }
 
@@ -416,6 +417,7 @@ SUPDECL(int) SUPSemEventMultiWaitNsRelIntr(PSUPDRVSESSION pSession, SUPSEMEVENTM
 
 SUPDECL(uint32_t) SUPSemEventMultiGetResolution(PSUPDRVSESSION pSession)
 {
+    RT_NOREF1(pSession);
     Assert(SUP_IS_SESSION_VALID(pSession));
     return RTSemEventMultiGetResolution();
 }
