@@ -1,4 +1,4 @@
-/* $Id: alloc.cpp 118412 2017-10-17 14:26:02Z bird $ */
+/* $Id: alloc.cpp 136886 2020-04-04 12:04:04Z bird $ */
 /** @file
  * IPRT - Memory Allocation.
  */
@@ -61,3 +61,13 @@ RTDECL(void *) RTMemDupExTag(const void *pvSrc, size_t cbSrc, size_t cbExtra, co
 }
 RT_EXPORT_SYMBOL(RTMemDupExTag);
 
+
+RTDECL(void *)  RTMemReallocZTag(void *pvOld, size_t cbOld, size_t cbNew, const char *pszTag) RT_NO_THROW_DEF
+{
+    void *pvDst = RTMemReallocTag(pvOld, cbNew, pszTag);
+    if (pvDst && cbNew > cbOld)
+        memset((uint8_t *)pvDst + cbOld, 0, cbNew - cbOld);
+    return pvDst;
+}
+RT_EXPORT_SYMBOL(RTMemReallocZTag);
+
