@@ -1,4 +1,4 @@
-/* $Id: thread.h 118810 2017-10-28 13:12:06Z bird $ */
+/* $Id: thread.h 136786 2020-04-01 12:40:26Z bird $ */
 /** @file
  * IPRT - Internal RTThread header.
  */
@@ -257,6 +257,9 @@ DECLHIDDEN(int)          rtThreadDoSetProcPriority(RTPROCPRIORITY enmPriority);
 DECLHIDDEN(void)         rtThreadClearTlsEntry(RTTLS iTls);
 DECLHIDDEN(void)         rtThreadTlsDestruction(PRTTHREADINT pThread); /* in tls-generic.cpp */
 #endif
+#ifdef RT_OS_WINDOWS
+DECLHIDDEN(void)         rtThreadWinTlsDestruction(void); /* in tls-win.cpp */
+#endif
 
 #ifdef ___iprt_asm_h
 
